// @ts-check}

//Given an express request, returns the client´s IP
const getClientIP = req => {
  const ip =
    (req.headers['x-forwarded-for'] || '').split(',').pop() ||
    req.connection.remoteAddress ||
    req.socket.remoteAddress ||
    req.connection.socket.remoteAddress;
  return ip === '::ffff:127.0.0.1' ? 'localhost' : ip;
};

// Given an express request, return a string with the IP and user-agent used
const getOrigin = req => {
  return ` desde ${getClientIP(req)} con ${req.headers['user-agent']}`;
};

// Given an express GET request, returns an object with the following properties:
//  pageSize: items per page (must be greater or equals to 1)
//  pageNum:  page number (page are numbered from 1)
//  search:   An optional search string for matching
const getPageOptions = (req, defaultPageSize = 10, defaultPageNum = 1) => {
  const pageSize = req.query.pageSize | parseInt(req.query.pageSize, 10);
  const pageNum = req.query.pageNum | parseInt(req.query.pageNum, 10);
  const search = req.query.search;

  const result = {
    pageSize: isNaN(pageSize) || pageSize < 1 ? defaultPageSize : pageSize,
    pageNum: isNaN(pageNum) || pageNum < 1 ? defaultPageNum : pageNum
  };

  if (search) {
    result.search = search;
  }
  return result;
};

module.exports = {
  getClientIP,
  getOrigin,
  getPageOptions
};
